==> localnews-base-service-2.0.1-20190414.114525-3-sources.jar: com/bxm/localnews/base/service/impl/AreaInfoServiceImpl.java <==
package com.bxm.localnews.base.service.impl;

import java.util.List;
import java.util.Optional;

import com.bxm.localnews.base.domain.AreaInfoMapper;
import com.bxm.localnews.base.dto.LocationFacadeDTO;
import com.bxm.localnews.base.service.AreaInfoService;
import com.bxm.localnews.base.service.LocationService;
import com.bxm.localnews.common.constant.RedisConfig;
import com.bxm.localnews.common.vo.AreaInfo;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.bxm.newidea.component.service.BaseService;
import com.fasterxml.jackson.core.type.TypeReference;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class AreaInfoServiceImpl extends BaseService implements AreaInfoService {

    private final AreaInfoMapper areaInfoMapper;

    private final RedisStringAdapter redisStringAdapter;

    private final LocationService locationService;

    @Autowired
    public AreaInfoServiceImpl(AreaInfoMapper areaInfoMapper, RedisStringAdapter redisStringAdapter, LocationService locationService) {
        this.areaInfoMapper = areaInfoMapper;
        this.redisStringAdapter = redisStringAdapter;
        this.locationService = locationService;
    }

    @Override
    public AreaInfo getAreaInfo(String code) {
        LocationFacadeDTO locationDTO = locationService.getInternalLocationByGeocode(code);

        KeyGenerator areaInfoKey = RedisConfig.AREA_INFO;
        TypeReference<List<AreaInfo>> areaInfoTypeReference = new TypeReference<List<AreaInfo>>() {
        };
        AreaInfo areaInfo = null;
        List<AreaInfo> areaInfoList = redisStringAdapter.get(areaInfoKey, areaInfoTypeReference);
        if (areaInfoList != null) {
            Optional<AreaInfo> areaInfoOptional = areaInfoList.stream().filter(x -> x.getCode().equals(code)).findFirst();
            if (areaInfoOptional.isPresent()) {
                areaInfo = areaInfoOptional.get();
            }
        }

        if (null == areaInfo) {
            areaInfoList = areaInfoMapper.selectByModel(null);
            redisStringAdapter.set(areaInfoKey, areaInfoList);
            areaInfo = areaInfoMapper.selectByCode(code);
        }

        if (null == areaInfo) {
            areaInfo = new AreaInfo();
        }

        areaInfo.setCode(locationDTO.getCode());
        areaInfo.setName(locationDTO.getName());

        return areaInfo;
    }

}

==> localnews-base-service-2.0.9-sources.jar: com/bxm/localnews/base/service/impl/AreaInfoServiceImpl.java <==
package com.bxm.localnews.base.service.impl;

import java.util.List;
import java.util.Optional;

import com.bxm.localnews.base.domain.AreaInfoMapper;
import com.bxm.localnews.base.service.AreaInfoService;
import com.bxm.localnews.base.service.LocationService;
import com.bxm.localnews.common.constant.RedisConfig;
import com.bxm.localnews.common.dto.LocationDetailDTO;
import com.bxm.localnews.common.vo.AreaInfo;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.bxm.newidea.component.service.BaseService;
import com.fasterxml.jackson.core.type.TypeReference;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class AreaInfoServiceImpl extends BaseService implements AreaInfoService {

    private final AreaInfoMapper areaInfoMapper;

    private final RedisStringAdapter redisStringAdapter;

    private final LocationService locationService;

    @Autowired
    public AreaInfoServiceImpl(AreaInfoMapper areaInfoMapper, RedisStringAdapter redisStringAdapter, LocationService locationService) {
        this.areaInfoMapper = areaInfoMapper;
        this.redisStringAdapter = redisStringAdapter;
        this.locationService = locationService;
    }

    @Override
    public AreaInfo getAreaInfo(String code) {
        if (StringUtils.isEmpty(code)) {
            logger.error("用户获取定位传参错误,code:{}",code);
        }

        LocationDetailDTO locationDTO = locationService.getInternalLocationByGeocode(code);

        KeyGenerator areaInfoKey = RedisConfig.AREA_INFO;
        TypeReference<List<AreaInfo>> areaInfoTypeReference = new TypeReference<List<AreaInfo>>() {
        };
        AreaInfo areaInfo = null;
        List<AreaInfo> areaInfoList = redisStringAdapter.get(areaInfoKey, areaInfoTypeReference);
        if (areaInfoList != null) {
            Optional<AreaInfo> areaInfoOptional = areaInfoList.stream().filter(x -> x.getCode().equals(code)).findFirst();
            if (areaInfoOptional.isPresent()) {
                areaInfo = areaInfoOptional.get();
            }
        }

        if (null == areaInfo) {
            areaInfoList = areaInfoMapper.selectByModel(null);
            redisStringAdapter.set(areaInfoKey, areaInfoList);
            areaInfo = areaInfoMapper.selectByCode(code);
        }

        if (null == areaInfo) {
            areaInfo = new AreaInfo();
        }

        areaInfo.setCode(locationDTO.getCode());
        areaInfo.setName(locationDTO.getName());
        areaInfo.setEnablePaidPromote(locationDTO.getEnablePaidPromote());

        return areaInfo;
    }

}
